@@ -14,6 +14,8 @@
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+import gi
+gi.require_version('Gtk', '3.0')
 from gi.repository import Gio, Gtk
 import logging
 logger = logging.getLogger('pasaffe_lib')
