@@ -1,5 +1,5 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
-### BEGIN LICENSE
+#
 # Copyright (C) 2011-2013 Marc Deslauriers <marc.deslauriers@canonical.com>
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-### END LICENSE
+#
 
 from . import pytwofish
 import operator
@@ -26,7 +26,8 @@ class TwofishCBC(pytwofish.Twofish):
     def _xor(self, string, pw):
         result = b''
         for k in range(len(string)):
-            result += struct.pack("B", operator.xor(ord(string[k:k+1]), ord(pw[k:k+1])))
+            result += struct.pack("B", operator.xor(ord(string[k:k + 1]),
+                                  ord(pw[k:k + 1])))
         return result
 
     def initCBC(self, iv=b"\0" * 16):
