@@ -19,12 +19,19 @@ import struct
 import hashlib
 import hmac
 import random
+import re
 import os
 import time
 import tempfile
 import shutil
-import pwd
+if os.name is "posix":
+    import pwd
+elif os.name is "nt":
+    import getpass
+# import pwd
 from binascii import hexlify, unhexlify
+from unidecode import unidecode
+from pasaffe_lib.helpers import PathEntry
 
 from . import pytwofishcbc
 import logging
@@ -47,6 +54,10 @@ class PassSafeFile:
         self.dbfile = None
         self.empty_folders = []
 
+        self.find_results = []
+        self.find_results_index = None
+        self.find_value = ""
+
         # These fields need converting between strings and bytes
         self.header_text = [0x03, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x11]
         self.record_text = [0x02, 0x03, 0x04, 0x05, 0x06, 0x0d]
@@ -143,7 +154,10 @@ class PassSafeFile:
         '''Writes database file'''
 
         # Set username
-        self.header[7] = pwd.getpwuid(os.getuid())[0]
+        if os.name is "posix":
+            self.header[7] = pwd.getpwuid(os.getuid())[0]
+        elif os.name is "nt":
+            self.header[7] = getpass.getuser()
         # Remove the old deprecated username field if it exists
         if 5 in self.header:
             del self.header[5]
@@ -765,3 +779,66 @@ class PassSafeFile:
             return self.records[uuid][5].replace("\n", "\r\n")
         else:
             return self.records[uuid][field]
+
+    def update_find_results(self, find, force=False):
+
+        if find == "":
+            self.find_results = []
+            self.find_results_index = None
+            self.find_value = ""
+            return
+
+        if find == self.find_value and force is False:
+            return
+
+        find_ascii = unidecode(find)
+        if find_ascii != find:
+            pat = re.compile(find + "|" + find_ascii, re.IGNORECASE)
+        else:
+            pat = re.compile(find, re.IGNORECASE)
+
+        record_list = (3, 5, 13)
+        results = []
+
+        for uuid in self.records:
+            found = False
+            for record_type in record_list:
+                if record_type in self.records[uuid]:
+                    if pat.search(
+                            self.records[uuid].get(record_type)):
+                        found = True
+                        break
+                    if pat.search(unidecode(
+                            self.records[uuid].get(record_type))):
+                        found = True
+                        break
+
+            if found is True:
+                entry = PathEntry(
+                    self.records[uuid][3],
+                    uuid,
+                    self.get_folder_list(uuid))
+                results.append(entry)
+
+        self.find_results = sorted(results)
+        self.find_results_index = None
+        self.find_value = find
+
+    def get_next_find_result(self, backwards=False):
+
+        if len(self.find_results) == 0:
+            return None
+
+        if self.find_results_index is None:
+            self.find_results_index = 0
+        elif backwards is False:
+            self.find_results_index += 1
+            if self.find_results_index == len(self.find_results):
+                self.find_results_index = 0
+        else:
+            if self.find_results_index == 0:
+                self.find_results_index = len(self.find_results) - 1
+            else:
+                self.find_results_index -= 1
+
+        return self.find_results[self.find_results_index].uuid
